@@ -26,7 +26,7 @@ variation_array = function(X, only_variation = FALSE){
 #'Modifying parameter type (pivot or cdp) other ilr basis can be generated
 #'
 #' @param dim number of components
-#' @param type if different than `pivot` (pivot balances) or `cdp` (codapack balances) default balances are returned.
+#' @param type if different than `pivot` (pivot balances) or `cdp` (codapack balances) default balances are returned, which computes a triangular Helmert matrix as defined by Egozcue et al., 2013.
 #' @return matrix
 #' @references
 #' Egozcue, J.J., Pawlowsky-Glahn, V., Mateu-Figueras, G. and Barceló-Vidal C. (2003).
@@ -38,7 +38,7 @@ variation_array = function(X, only_variation = FALSE){
 ilr_basis = function(dim, type = 'default'){
   B = ilr_basis_default(dim)
   if(type == 'pivot'){
-    return((-B)[,ncol(B):1][nrow(B):1,])
+    return((-B)[,ncol(B):1, drop = FALSE][nrow(B):1,])
   }
   if(type == 'cdp'){
     return(sbp_basis(cdp_partition(dim)))
@@ -71,10 +71,10 @@ alr_basis = function(dim, denominator = dim, numerator = which(denominator != 1:
   res = alr_basis_default(dim)
   res = cbind(res, 0)
   if(dim != denominator){
-    res[c(denominator, dim),] = res[c(dim, denominator),]
-    res[,c(denominator, dim)] = res[,c(dim, denominator)]
+    res[c(denominator, dim),] = res[c(dim, denominator),, drop = FALSE]
+    res[,c(denominator, dim)] = res[,c(dim, denominator), drop = FALSE]
   }
-  res[,numerator]
+  res[,numerator, drop = FALSE]
 }
 
 fillPartition = function(partition, row, left, right){
@@ -275,7 +275,7 @@ pc_basis = function(X){
   X = as.matrix(X)
   lX =  log(X)
   SVD = svd(scale(lX - rowMeans(lX), scale = FALSE))
-  B = SVD$v[,-ncol(X)]
+  B = SVD$v[,-ncol(X), drop = FALSE]
   B
 }
 
@@ -346,10 +346,10 @@ pb_basis = function(X, method, rep = 0, ordering = TRUE, ...){
     id = seq_along(sbp)
     sbp.exp = paste(sprintf("%s = %s ~ %s", paste0('P', id), nms[,1], nms[,2]),
                     collapse=', ')
-    B = eval(parse(text = sprintf("sbp_basis(%s,data=df)", sbp.exp)))[,rev(id)]
+    B = eval(parse(text = sprintf("sbp_basis(%s,data=df)", sbp.exp)))[,rev(id), drop = FALSE]
   }
   if(ordering){
-    B = B[,order(apply(coordinates(X, B), 2, stats::var), decreasing = TRUE)]
+    B = B[,order(apply(coordinates(X, B), 2, stats::var), decreasing = TRUE), drop = FALSE]
   }
   B
 }
@@ -443,7 +443,7 @@ coordinates = function(X, basis = 'ilr', label = NULL, sparse_basis = FALSE){
           }else{
             if(basis == 'pb'){
               if(ncol(RAW.coda) > 15){
-                message("Number of columns is high for 'pb' method. Depending on your system this computation can take too long. Consider using an approximate method. Consult 'pb_basis' function for more details.")
+                message("Number of columns is high for 'pb' method. Depending on your system this computation can take too long. Consider using an approximate method. Consult 'pb_basis()' function for more details.")
               }
               basis = pb_basis(RAW.coda, method = 'exact')
               COORD.coda = coordinates_basis(RAW.coda, basis, sparse = FALSE)
@@ -466,6 +466,9 @@ coordinates = function(X, basis = 'ilr', label = NULL, sparse_basis = FALSE){
       if(is.null(label)){
         label = 'x'
       }
+      if(max(colSums(basis)) > .Machine$double.eps^0.5){
+        warning("Supplied basis matrix is not a log-contrast.")
+      }
       dim = nrow(basis)
       coord.dim = ncol(basis)
       RAW.coda = matrix(RAW[sel_compositional, ], ncol = dim)
@@ -487,7 +490,7 @@ coordinates = function(X, basis = 'ilr', label = NULL, sparse_basis = FALSE){
   }
   class(COORD) = class_type
   attr(COORD, 'basis') = basis
-  row.names(COORD) = row.names(X)
+  suppressWarnings(row.names(COORD) <- row.names(X))
   set.coda(COORD)
 }
 
@@ -567,7 +570,7 @@ composition = function(H, basis = NULL, label = 'x', sparse_basis = FALSE){
     RAW = as.data.frame(RAW)
   }
   class(RAW) = setdiff(class_type, 'coda')
-  row.names(RAW) = row.names(H)
+  suppressWarnings(row.names(RAW) <- row.names(H))
   #attr(RAW, 'basis') = basis
   RAW
 }
